﻿using Hotline.Share.Dtos.DataSharing.Enterprise.Send;
using MapsterMapper;
using Sharing.Share.Dtos.DataSharing.Enterprise;
using XF.Domain.Dependency;
using XF.Domain.Repository;

namespace Hotline.DataSharing.Enterprise
{
    public class EnterpriseService : IEnterpriseService, IScopeDependency
    {
        private readonly EnterpriseClient _enterpriseClient;
        private readonly IMapper _mapper;
        private readonly IRepository<DsDataWorkOrderSend> _dataWorkOrderSendRepository;
        private readonly IRepository<DsDataWorkOrderCancel> _dataWorkOrderCancelRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        public EnterpriseService(EnterpriseClient enterpriseClient,
            IMapper mapper, IRepository<DsDataWorkOrderSend> dataWorkOrderSendRepository,
             IRepository<DsDataWorkOrderCancel> dataWorkOrderCancelRepository)
        {
            _enterpriseClient = enterpriseClient;
            _mapper = mapper;
            _dataWorkOrderSendRepository = dataWorkOrderSendRepository;
            _dataWorkOrderCancelRepository = dataWorkOrderCancelRepository;
        }

        /// <summary>
        /// 企业数据推送
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task EnterpriseSendPusher(DsDataWorkOrderSend dto, CancellationToken cancellationToken)
        {
            var pushWorkOrder = _mapper.Map<Share.Dtos.DataSharing.Enterprise.Send.PushWorkOrder>(dto);
            var request = new PushWorkOrderRequest();
            request.SetData(pushWorkOrder);
            var response = await _enterpriseClient.RequestAsync<PushWorkOrderRequest, EnterpriseResponse>(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.code == 200 && response.success)
                    dto.SyncState = "1";
                else
                    dto.SyncState = "2";

                dto.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _dataWorkOrderSendRepository.UpdateAsync(dto);
            }
        }

        /// <summary>
        /// 企业撤销
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task EnterpriseCancelPusher(DsDataWorkOrderCancel dto, CancellationToken cancellationToken)
        {
            var cancelWorkOrder = _mapper.Map<Share.Dtos.DataSharing.Enterprise.Send.CancelWorkOrder>(dto);
            var request = new CancelWorkOrderRequest();
            request.SetData(cancelWorkOrder);
            var response = await _enterpriseClient.RequestAsync<CancelWorkOrderRequest, EnterpriseResponse>(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.code == 200 && response.success)
                    dto.SyncState = "1";
                else
                    dto.SyncState = "2";

                dto.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _dataWorkOrderCancelRepository.UpdateAsync(dto);
            }
        }
    }
}
